---
title: <span class="badge object-type-scalar"></span> GigabytesPerSecond
---
# <span class="badge object-type-scalar"></span> GigabytesPerSecond

Data rate: gigabytes/sec

## Definition

```python
# Data rate: gigabytes/sec
GigabytesPerSecond: typing.Literal["GBs"] = "GBs"
```
